package com.datacloudsec.scan.service.impl;

import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.WifiMapper;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IWifi;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.PoiExcelUtils;
import com.datacloudsec.utils.ReflectUtils;
import java.io.File;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/WifiService.class */
public class WifiService implements IWifi {
    private WifiMapper wifiMapper = (WifiMapper) InstanceUtil.newDaoInstance(WifiMapper.class);
    private IEngine engineService = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);

    public void delWifiSta() throws Exception {
        this.wifiMapper.delWifiSta();
    }

    public void insertWifiSta(List<Map<String, Object>> list, Date time) throws Exception {
        this.wifiMapper.insertWifiSta(list, time);
    }

    public List<Map<String, Object>> getWifiSta(String mac) throws Exception {
        return this.wifiMapper.getWifiSta(mac);
    }

    public File export() throws Exception {
        HSSFWorkbook hssfWorkbook = writeContent();
        File f = new File(Constant.WORK_DIR, ObjectUtil.getString(String.valueOf(System.currentTimeMillis()) + ".xls", ""));
        FileOutputStream out = null;
        try {
            try {
                out = FileUtils.openOutputStream(f);
                hssfWorkbook.write(out);
                IOUtils.closeQuietly(out);
                return f;
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(out);
            throw th;
        }
    }

    private HSSFWorkbook writeContent() throws Exception {
        Object cellValue;
        Map<String, Object> resultMap;
        String[] headers = {"MAC地址@mac@6000", "SSID@ssid@8000", "是否为隐藏WIFI@hidden@5000", "是否开启WPS@wps@5000", "弱密码@pwd@4000", "无线信道号@channel@4000", "加密方式@privacy@4000", "认证方式@auth@4000", "无线信标@beacons@4000", "信号强弱@power@4000", "生产厂商@manufacture@6000", "已连接客户端MAC地址@clients@12000"};
        PoiExcelUtils poiExcelUtil = new PoiExcelUtils();
        HSSFWorkbook hssfWorkbook = poiExcelUtil.getHSSFWorkbook();
        HSSFSheet hssfSheet = poiExcelUtil.getHSSFSheet(hssfWorkbook, "WIFI扫描结果");
        poiExcelUtil.writeHeader(hssfWorkbook, hssfSheet, headers, "WIFI扫描结果");
        Map<String, Object> wifiStatus = this.engineService.wifiIsSearch();
        String status = ObjectUtil.getString(wifiStatus.get("result"), "");
        List<Map<String, Object>> dataList = new ArrayList<>();
        if (status.contains("run") && (resultMap = (Map) this.engineService.wifiGetResult().get("result")) != null && resultMap.size() > 0) {
            for (Map.Entry<String, Object> e : resultMap.entrySet()) {
                dataList.add((Map) e.getValue());
            }
        }
        int rownum = 2;
        HSSFCellStyle cellStyle = poiExcelUtil.createContentCellStyle(hssfWorkbook);
        if (!CollectionUtils.isEmpty(dataList)) {
            int size = dataList.size();
            for (int j = 0; j < size; j++) {
                HSSFRow row = hssfSheet.createRow(rownum);
                Map<String, Object> map = dataList.get(j);
                int len = headers.length;
                for (int i = 0; i < len; i++) {
                    HSSFCell cell = row.createCell(i);
                    String key = ObjectUtil.getString(headers[i].split("@")[1].trim(), "");
                    if (map != null) {
                        cellValue = map.get(key);
                    } else {
                        cellValue = ReflectUtils.getValueOfGetIncludeObjectFeild(dataList.get(j), key);
                    }
                    if ("privacy".equals(key)) {
                        if (cellValue.toString().contains("OPN")) {
                            cellValue = "未加密";
                        }
                    } else if ("power".equals(key)) {
                        int power = ObjectUtil.getInt(cellValue, 0);
                        if (power > -40) {
                            cellValue = "强";
                        } else if (power >= -90 && power <= -40) {
                            cellValue = "正常";
                        } else {
                            cellValue = "弱";
                        }
                    } else if ("clients".equals(key)) {
                        cellValue = StringUtils.join((List) cellValue, "，");
                    } else if ("hidden".equals(key)) {
                        if (ObjectUtil.getBoolean(cellValue)) {
                            cellValue = "是";
                        } else {
                            cellValue = "否";
                        }
                    } else if ("wps".equals(key)) {
                        if (!"".equals(ObjectUtil.getString(cellValue, ""))) {
                            cellValue = "是";
                        } else {
                            cellValue = "否";
                        }
                    } else if ("pwd".equals(key) && cellValue != null) {
                        Map<String, Object> pwd = (Map) cellValue;
                        cellValue = pwd.get("password");
                    }
                    poiExcelUtil.cellValueHandler(cell, cellValue);
                    cell.setCellStyle(cellStyle);
                }
                rownum++;
            }
        }
        return hssfWorkbook;
    }
}
